diff --git a/DEVELOPMENT.md b/DEVELOPMENT.md
index f5b4aa651380693a7327c40c5c6e8e2efb38b0a3..e5e605dc8fda374fd5756aa7d7b43dbce8055657 100644
--- a/DEVELOPMENT.md
+++ b/DEVELOPMENT.md
@@ -236,7 +236,7 @@ cat source_env.local
 
 export HYDRA_ADMIN_URL=http://localhost:4445
 export KRATOS_PUBLIC_URL=http://localhost/api
-export KRATOS_ADMIN_URL=http://localhost:8000
+export KRATOS_ADMIN_URL=http://localhost:8000/admin
 export LOGIN_PANEL_URL=http://localhost/web
 export DATABASE_URL="mysql+pymysql://stackspin:stackspin@localhost/stackspin"
 ```
diff --git a/requirements.txt b/requirements.txt
index d4d017d9b2a713675284efcfa240011a931f5b50..a98cfdc41529a42ab73ba6a453ef6deb66846be8 100644
--- a/requirements.txt
+++ b/requirements.txt
@@ -31,7 +31,7 @@ tomli==1.2.3
 typing-extensions==4.1.1
 urllib3==1.26.8
 Werkzeug==2.0.3
-ory-kratos-client==0.8.0a2
+ory-kratos-client==0.9.0a2
 pymysql
 Flask-SQLAlchemy
 hydra-client
diff --git a/run_app.sh b/run_app.sh
index 4d6074a24e199e0027a39521eb3a0061f6121e09..7710af382790ac66939d342021035c3ee1cd3f9b 100755
--- a/run_app.sh
+++ b/run_app.sh
@@ -28,7 +28,7 @@ export TOKEN_URL="https://sso.init.stackspin.net/oauth2/token"
 
 # Login facilitator paths
 export KRATOS_PUBLIC_URL=http://localhost/kratos
-export KRATOS_ADMIN_URL=http://localhost:8000
+export KRATOS_ADMIN_URL=http://localhost:8000/admin
 export HYDRA_PUBLIC_URL="https://sso.init.stackspin.net"
 export HYDRA_ADMIN_URL=http://localhost:4445
 export LOGIN_PANEL_URL=http://localhost/web/
diff --git a/web/static/base.js b/web/static/base.js
index 2b2e07f233881f74520d3cdbc692cf02103cbc62..a98e4a0fe3bc128c008e3f08ee5c1a5d4dba2387 100644
--- a/web/static/base.js
+++ b/web/static/base.js
@@ -56,8 +56,8 @@ function flow_login() {
         url: uri,
         success: function(data) {
 
-            // Render login form (group: password)
-            var html = render_form(data, 'password');
+            // Render login form (group: profile)
+            var html = render_form(data, 'profile');
             $("#contentLogin").html(html);
 
         },
@@ -134,10 +134,12 @@ function flow_settings() {
             }
 
 
+            // FIXME: This seems to be not necessary anymore in kratos 0.9.0
+            // because they moved the password field to the profile group
             // Render the password & profile form based on the fields we got
             // from the API
-            var html = render_form(data, 'password');
-            $("#contentPassword").html(html);
+            // var html = render_form(data, 'profile');
+            // $("#contentPassword").html(html);
 
             html = render_form(data, 'profile');
             $("#contentProfile").html(html);
@@ -309,7 +311,7 @@ function getFormElement(type, name, value) {
     }
 
 
-    if (name == 'password_identifier') {
+    if (name == 'identifier') {
         return getFormInput(
                 'email',
                 name,